<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="48"/>
        <source>GME Plugin</source>
        <translation>GME Module</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="51"/>
        <source>Game Music Files</source>
        <translation>Spel Muziek Bestanden</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="116"/>
        <source>About GME Audio Plugin</source>
        <translation>Over de GME Audio Module</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>GME Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Deze module faciliteert in het afspelen van spelmuziek door gebruik van de Game_Music_Emu bibliotheek</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
